{% extends 'baykeshop/base_site.html' %}
{% load i18n %}

{% block main %}
<section class="bk-section">
    <div class="bk-container">
        <div class="bk-columns bk-is-centered">
            <div class="bk-column bk-is-5">
                <div class="bk-box p-6">
                    <h1 class="bk-title bk-has-text-centered">{% translate 'Password reset' %}</h1> 
                    <p>{% translate "Your password has been set.  You may go ahead and log in now." %}</p>
                    <p class="mt-3"><a class="bk-button bk-is-link bk-is-fullwidth" href="{% url 'member:login' %}">{% translate 'Log in' %}</a></p>
                </div>
            </div>
        </div>
    </div>
</section>
{% endblock %}

