{% extends 'baykeshop/base_site.html' %}
{% load i18n %}

{% block main %}
<section class="bk-section">
    <div class="bk-container">
        <div class="bk-columns bk-is-centered">
            <div class="bk-column bk-is-5">
                <div class="bk-box p-6">
                    <h1 class="bk-title bk-has-text-centered">{% translate 'Password reset' %}</h1> 
                    <div class="bk-notification">
                        <p>{% translate 'We’ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.' %}</p>

                        <p>{% translate 'If you don’t receive an email, please make sure you’ve entered the address you registered with, and check your spam folder.' %}</p>
                    </div> 
                </div>
            </div>
        </div>
    </div>
</section>
{% endblock %}