# Generated by Django 4.2.17 on 2025-05-12 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('member', '0002_alter_baykeshopuser_mobile_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='baykeshopuseraddress',
            name='email',
            field=models.EmailField(blank=True, default='', max_length=254, verbose_name='邮箱'),
        ),
    ]
