{% extends 'baykeshop/base_site.html' %}
{% load i18n %}

{% block main %}
<section class="bk-section">
    <div class="bk-container">
        <div class="bk-columns bk-is-centered">
            <div class="bk-column bk-is-5">
                <div class="bk-box p-6">
                    <h1 class="bk-title bk-has-text-centered">{% translate 'Password reset confirmation' %}</h1>
                    {% if validlink %}
                    <div class="bk-notification bk-is-warning bk-is-light">
                        <p>{% translate "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
                    </div>
                    <form method="post">
                        {% csrf_token %}
                        <input class="bk-is-hidden" autocomplete="username" value="{{ form.user.get_username }}">
                        {{ form.as_bulma }}
                        <div class="bk-field">
                            <div class="bk-control">
                                <button class="bk-button bk-is-link bk-is-fullwidth" type="submit">{% translate 'Change my password' %}</button>
                            </div>
                        </div>
                    </form>
                    {% else %}
                    <p>
                        {% translate "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}
                    </p>
                    {% endif %}
                </div>
            </div>
        </div>
    </div> 
</section>
{% endblock %}