# Generated by Django 4.2.17 on 2025-05-13 13:03

import baykeshop.db.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0005_baykeshoporders_email'),
    ]

    operations = [
        migrations.AddField(
            model_name='baykeshopgoodssku',
            name='email_message',
            field=baykeshop.db.fields.RichTextField(blank=True, default='', verbose_name='虚拟商品邮件内容'),
        ),
    ]
