# Generated by Django 4.2.17 on 2025-05-07 13:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0003_alter_baykeshopgoodssku_line_price_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='baykeshopgoods',
            name='is_virtual',
            field=models.BooleanField(default=False, help_text='虚拟商品不需要物流', verbose_name='是否为虚拟商品'),
        ),
    ]
