{% extends 'baykeshop/base_site.html' %}
{% load i18n %}

{% block main %}
<section class="bk-section">
    <div class="bk-container">
        <div class="bk-columns bk-is-centered">
            <div class="bk-column bk-is-5">
                <div class="bk-box p-6">
                    <h1 class="bk-title bk-has-text-centered">{% translate 'Password reset' %}</h1> 
                    <div class="bk-notification bk-is-warning bk-is-light">
                    <p>{% translate 'Forgotten your password? Enter your email address below, and we’ll email instructions for setting a new one.' %}</p>
                    </div>
                    <form action="" method="post">
                        {% csrf_token %}
                        {{ form.as_bulma }}
                        <div class="bk-field">
                            <button type="submit" class="bk-button bk-is-link bk-is-fullwidth">
                                <span class="bk-icon">
                                    <i class="mdi mdi-form-textbox-password"></i>
                                </span>
                                <span>
                                    {% translate 'Reset my password' %}
                                </span>
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</section>
{% endblock %}