# Generated by Django 4.2.17 on 2025-06-10 12:29

import baykeshop.db.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0006_baykeshopgoodssku_email_message'),
    ]

    operations = [
        migrations.AlterField(
            model_name='baykeshopgoodssku',
            name='email_message',
            field=baykeshop.db.fields.RichTextField(blank=True, default='', help_text='如果SPU整体为虚拟商品，则填写虚拟商品邮件内容，付款成功后，会发送邮件给用户', verbose_name='虚拟商品邮件内容'),
        ),
    ]
